@@ -58,7 +58,7 @@
 #define BANNER "220 "PROGNAME" "PROGRAM_VERSION"\r\n"
 
 #ifdef FD_SETSIZE
-#define MAX_CLIENTS (FD_SETSIZE > 150 ? 150 : FD_SETSIZE - 1)
+#define MAX_CLIENTS (FD_SETSIZE >= 160 ? 150 : FD_SETSIZE - 10)
 #else
 #define MAX_CLIENTS (150)
 #endif /* FD_SETSIZE */
@@ -120,7 +120,7 @@ static void exit_signal_handler(const int signo)
 }
 
 
-/* Show some stats where we catch USR1 */
+/* Show some stats when we catch USR1 */
 static void usr1_signal_handler(const int signo)
 {
   struct rusage u;
@@ -423,6 +423,7 @@ extern int main(int argc, char **argv)
   int slot, errors;
   struct sigaction sa;
   struct stat sb;
+  struct timeval tv;
   
   openlog(PROGNAME, LOG_PID, LOG_DAEMON);
 
@@ -529,8 +530,11 @@ extern int main(int argc, char **argv)
     rset = svrset;
     wset = svwset;
     
-    if ((nsel = select(maxsd + 1, &rset, &wset, NULL, NULL)) == -1
-	&& errno !=EINTR) {
+    /* Wake up at least every 60 seconds to perform some cleanup */
+    tv.tv_sec = 60;
+    tv.tv_usec = 0;
+    if ((nsel = select(maxsd + 1, &rset, &wset, NULL, &tv)) == -1
+	&& errno != EINTR) {
       syslog(LOG_ERR, "error in select(): %s", strerror(errno));
       if (++errors >= 3) {
 	syslog(LOG_ERR, "too many errors, aborting");
